@@ -232,8 +232,9 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   nbrOfCellsPerQcUnit <- unlist(nbrOfCellsPerQcUnit, use.names=FALSE);
   nbrOfQcCells <- sum(nbrOfCellsPerQcUnit);
   verbose && printf(verbose,
-                        "Number of QC cells: %d in %d QC units (%.1fMB)\n",
-              nbrOfQcCells, nbrOfQcUnits, object.size(destQcUnits)/1024^2);
+             "Number of QC cells: %d in %d QC units (%s)\n",
+             nbrOfQcCells, nbrOfQcUnits,
+             hsize(object.size(destQcUnits), digits = 2L, standard = "IEC"))
 
 
 
@@ -420,7 +421,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
     }
 
     if (verbose && isVisible(verbose)) {
-      cat(sprintf(" => RAM: %.fMB\n", object.size(srcUnits)/1024^2));
+      printf(verbose, " => RAM: %s\n", hsize(object.size(srcUnits), digits = 2L, standard = "IEC"))
     }
 
     # Sanity check
