@@ -231,8 +231,8 @@ setMethodS3("as.character", "AffymetrixCelSet", function(x, ...) {
   } else {
     s <- c(s, sprintf("Time period: [not reported if more than %.0f arrays]", as.double(maxCount)));
   }
-  s <- c(s, sprintf("Total file size: %.2fMB", getFileSize(this)/1024^2));
-  s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
+  s <- c(s, sprintf("Total file size: %s", hsize(getFileSize(this), digits = 2L, standard = "IEC")))
+
   GenericSummary(s);
 }, protected=TRUE)
 
