@@ -79,7 +79,7 @@ setMethodS3("extractMatrix", "AffymetrixCelSet", function(this, cells=NULL, ...,
   df <- matrix(naValue, nrow=ncells, ncol=nbrOfArrays);
   colnames(df) <- arrayNames;
   verbose && str(verbose, df);
-  verbose && printf(verbose, "RAM: %.2fMB\n", object.size(df)/1024^2);
+  verbose && printf(verbose, "RAM: %s\n", hsize(object.size(df), digits = 2L, standard = "IEC"))
   verbose && exit(verbose);
 
   if (!is.null(cells)) {
