@@ -3,8 +3,7 @@ setConstructorS3("AromaUfcFile", function(...) {
   this <- extend(AromaUnitTabularBinaryFile(...), "AromaUfcFile");
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  setAttributesByTags(this)
 
   this;
 })
