@@ -180,7 +180,7 @@ setMethodS3("process", "ChipEffectGroupMerge", function(this, ..., force=FALSE,
   nbrOfArrays <- length(ces);
   res <- vector("list", nbrOfArrays);
   for (kk in seq_len(nbrOfArrays)) {
-    ce <- getFile(ces, kk);
+    ce <- ces[[kk]];
     verbose && enter(verbose, sprintf("Array #%d of %d ('%s')", kk, nbrOfArrays, getName(ce)));
 #    verbose && print(verbose, ce);
 
