@@ -12,8 +12,8 @@ setMethodS3("exportAromaSignalBinaryFileList", "CnChipEffectFile", function(this
     }
   }
 
-  NextMethod("exportAromaSignalBinaryFileList", this, whats=whats, ...);
-})
+  NextMethod("exportAromaSignalBinaryFileList", whats=whats);
+}, protected=TRUE)
 
 
 ############################################################################
