@@ -198,7 +198,7 @@ setMethodS3("getConfidenceScoreSet", "CrlmmModel", function(this, ..., verbose=F
   } # for (kk ...)
   verbose && exit(verbose);
 
-  res <- AromaUnitSignalBinarySet$byPath(outPath, pattern=",confidenceScores.acf$");
+  res <- AromaUnitSignalBinarySet$byPath(outPath, pattern=",confidenceScores[.]acf$");
 
   res;
 }) # getConfidenceScoreSet()
