@@ -9,7 +9,7 @@ setMethodS3("calculateWeights", "ExonRmaPlm", function(this, units=NULL, ram=NUL
   resFcn <- function(unit, mergeGroups) {
     nbrOfGroups <- length(unit);
     if (mergeGroups) {
-      y <- do.call("rbind", lapply(unit, FUN=.subset2, "eps"));
+      y <- do.call(rbind, lapply(unit, FUN=.subset2, "eps"));
       y <- log2(y);
       madMerged <- 1.4826 * median(abs(y));
     }
@@ -69,6 +69,13 @@ setMethodS3("calculateWeights", "ExonRmaPlm", function(this, units=NULL, ram=NUL
     unitsToDo <- findUnitsTodo(ws, units=units);
   }
 
+  ## Already done?
+  if (length(unitsToDo) == 0) {
+    verbose && cat(verbose, "All weights already calculated. Skipping.")
+    verbose && exit(verbose)
+    return(invisible(ws))
+  }
+
   verbose && printf(verbose, "Number of units: %d\n", nbrOfUnits);
 
   unitsPerChunk <- ram * 100000/length(getDataSet(this));
@@ -134,6 +141,9 @@ setMethodS3("calculateWeights", "ExonRmaPlm", function(this, units=NULL, ram=NUL
   gc <- gc();
   verbose && print(verbose, gc);
 
+  ## Generate checksum files
+  wsZ <- getChecksumFileSet(ws)
+
   verbose && exit(verbose);
 
   invisible(ws);
