@@ -296,7 +296,10 @@ setMethodS3("calculateResidualSet", "ProbeLevelModel", function(this, units=NULL
     })
 
     # Rename temporary file
-    pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+    popTemporaryFile(pathnameT, verbose=verbose);
+
+    ## Generate checksum file
+    dfZ <- getChecksumFile(pathname)
 
     verbose && exit(verbose);
 
