@@ -673,7 +673,7 @@ setMethodS3("process", "ReseqCrosstalkCalibration", function(this, ..., force=FA
       yAll <- verbose2 <- NULL;
 
       # Rename temporary file
-      pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+      popTemporaryFile(pathnameT, verbose=verbose);
 
       gc <- gc();
       verbose && print(verbose, gc);
@@ -684,6 +684,9 @@ setMethodS3("process", "ReseqCrosstalkCalibration", function(this, ..., force=FA
     # Test if calibrated data file can be retrieved
     dfC <- newInstance(df, pathname);
 
+    ## Create checksum file
+    dfCZ <- getChecksumFile(dfC)
+
     # Not needed anymore
     df <- NULL; # Not needed anymore
 
