@@ -26,12 +26,9 @@
 setConstructorS3("UgpGenomeInformation", function(..., .ugp=NULL, .verify=TRUE) {
   this <- extend(GenomeInformation(..., .verify=FALSE), "UgpGenomeInformation",
     "cached:.ugp" = .ugp
-  );
-  if (.verify) {
-    if (!is.null(getPathname(this)))
-      verify(this);
-  }
-  this;
+  )
+  if (.verify && isFile(this)) verify(this)
+  this
 })
 
 
@@ -262,7 +259,7 @@ setMethodS3("getData", "UgpGenomeInformation", function(this, units=NULL, fields
 
   # Reorder?
   if (!is.null(orderBy)) {
-    o <- do.call("order", args=as.list(data[,orderBy,drop=FALSE]));
+    o <- do.call(order, args=as.list(data[,orderBy,drop=FALSE]));
     data <- data[o,,drop=FALSE];
     # Not needed anymore
     o <- NULL;
