@@ -64,8 +64,7 @@ setConstructorS3("WeightsFile", function(..., probeModel=c("pm")) {
   })
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  setAttributesByTags(this)
 
   this;
 })
