@@ -106,7 +106,7 @@ setMethodS3("doGCRMA", "AffymetrixCelSet", function(csR, arrays=NULL, type=c("fu
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (!is.null(arrays)) {
     verbose && enter(verbose, "GCRMA/Extracting subset of arrays");
-    csR <- extract(csR, arrays);
+    csR <- extract(csR, arrays, onDuplicates="error");
     verbose && cat(verbose, "Data subset");
     verbose && print(verbose, csR);
     verbose && exit(verbose);
@@ -135,7 +135,7 @@ setMethodS3("doGCRMA", "AffymetrixCelSet", function(csR, arrays=NULL, type=c("fu
     # Try to load the final TCN data set
     ces <- tryCatch({
       cesT <- ChipEffectSet$byName(dataSet, tags=tags, chipType=chipType);
-      extract(cesT, fullnames, onMissing="error");
+      extract(cesT, fullnames, onMissing="error", onDuplicates="error");
     }, error=function(ex) { NULL });
 
     # Done?
