@@ -66,7 +66,7 @@ if (is.null(ugp)) {
 print(ugp);
 
 
-for (kk in seq(along=csvList)) {
+for (kk in seq_along(csvList)) {
   csv <- csvList[[kk]];
   print(csv);
   units <- importFrom(ugp, csv, verbose=log);
@@ -82,7 +82,7 @@ for (kk in seq(along=csvList)) {
 if (!exists("srcFileTags", mode="list")) {
   srcFileTags <- list();
   srcFiles <- c(list(cdf), csvList);
-  for (kk in seq(along=srcFiles)) {
+  for (kk in seq_along(srcFiles)) {
     srcFile <- srcFiles[[kk]];
     tags <- list(
       filename=getFilename(srcFile), 
@@ -100,7 +100,7 @@ footer$createdBy = list(
   fullname = "Henrik Bengtsson", 
   email = sprintf("%s@%s", "henrik.bengtsson", "aroma-project.org")
 );
-names(srcFileTags) <- sprintf("srcFile%d", seq(along=srcFileTags));
+names(srcFileTags) <- sprintf("srcFile%d", seq_along(srcFileTags));
 footer$srcFiles <- srcFileTags;
 writeFooter(ugp, footer);
 
